==> sagemaker-1.42.1-sources.jar: software/amazon/awscdk/services/sagemaker/CfnModelProps.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * Properties for defining a `AWS::SageMaker::Model`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.5.0 (build 46538f8)", date = "2020-06-01T16:52:35.013Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sagemaker.$Module.class, fqn = "@aws-cdk/aws-sagemaker.CfnModelProps")
@software.amazon.jsii.Jsii.Proxy(CfnModelProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnModelProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::SageMaker::Model.ExecutionRoleArn`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-executionrolearn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    @org.jetbrains.annotations.NotNull java.lang.String getExecutionRoleArn();

    /**
     * `AWS::SageMaker::Model.Containers`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-containers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.lang.Object getContainers() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.ModelName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-modelname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.lang.String getModelName() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.PrimaryContainer`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-primarycontainer
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.lang.Object getPrimaryContainer() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.Tags`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.VpcConfig`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-vpcconfig
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.lang.Object getVpcConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnModelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnModelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String executionRoleArn;
        private java.lang.Object containers;
        private java.lang.String modelName;
        private java.lang.Object primaryContainer;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;
        private java.lang.Object vpcConfig;

        /**
         * Sets the value of {@link CfnModelProps#getExecutionRoleArn}
         * @param executionRoleArn `AWS::SageMaker::Model.ExecutionRoleArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder executionRoleArn(java.lang.String executionRoleArn) {
            this.executionRoleArn = executionRoleArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getContainers}
         * @param containers `AWS::SageMaker::Model.Containers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder containers(software.amazon.awscdk.core.IResolvable containers) {
            this.containers = containers;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getContainers}
         * @param containers `AWS::SageMaker::Model.Containers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder containers(java.util.List<java.lang.Object> containers) {
            this.containers = containers;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getModelName}
         * @param modelName `AWS::SageMaker::Model.ModelName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder modelName(java.lang.String modelName) {
            this.modelName = modelName;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getPrimaryContainer}
         * @param primaryContainer `AWS::SageMaker::Model.PrimaryContainer`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder primaryContainer(software.amazon.awscdk.core.IResolvable primaryContainer) {
            this.primaryContainer = primaryContainer;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getPrimaryContainer}
         * @param primaryContainer `AWS::SageMaker::Model.PrimaryContainer`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder primaryContainer(software.amazon.awscdk.services.sagemaker.CfnModel.ContainerDefinitionProperty primaryContainer) {
            this.primaryContainer = primaryContainer;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getTags}
         * @param tags `AWS::SageMaker::Model.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder tags(java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getVpcConfig}
         * @param vpcConfig `AWS::SageMaker::Model.VpcConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpcConfig(software.amazon.awscdk.core.IResolvable vpcConfig) {
            this.vpcConfig = vpcConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getVpcConfig}
         * @param vpcConfig `AWS::SageMaker::Model.VpcConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpcConfig(software.amazon.awscdk.services.sagemaker.CfnModel.VpcConfigProperty vpcConfig) {
            this.vpcConfig = vpcConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnModelProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnModelProps build() {
            return new Jsii$Proxy(executionRoleArn, containers, modelName, primaryContainer, tags, vpcConfig);
        }
    }

    /**
     * An implementation for {@link CfnModelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnModelProps {
        private final java.lang.String executionRoleArn;
        private final java.lang.Object containers;
        private final java.lang.String modelName;
        private final java.lang.Object primaryContainer;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;
        private final java.lang.Object vpcConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.executionRoleArn = this.jsiiGet("executionRoleArn", java.lang.String.class);
            this.containers = this.jsiiGet("containers", java.lang.Object.class);
            this.modelName = this.jsiiGet("modelName", java.lang.String.class);
            this.primaryContainer = this.jsiiGet("primaryContainer", java.lang.Object.class);
            this.tags = this.jsiiGet("tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
            this.vpcConfig = this.jsiiGet("vpcConfig", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String executionRoleArn, final java.lang.Object containers, final java.lang.String modelName, final java.lang.Object primaryContainer, final java.util.List<software.amazon.awscdk.core.CfnTag> tags, final java.lang.Object vpcConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.executionRoleArn = java.util.Objects.requireNonNull(executionRoleArn, "executionRoleArn is required");
            this.containers = containers;
            this.modelName = modelName;
            this.primaryContainer = primaryContainer;
            this.tags = tags;
            this.vpcConfig = vpcConfig;
        }

        @Override
        public java.lang.String getExecutionRoleArn() {
            return this.executionRoleArn;
        }

        @Override
        public java.lang.Object getContainers() {
            return this.containers;
        }

        @Override
        public java.lang.String getModelName() {
            return this.modelName;
        }

        @Override
        public java.lang.Object getPrimaryContainer() {
            return this.primaryContainer;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        public java.lang.Object getVpcConfig() {
            return this.vpcConfig;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("executionRoleArn", om.valueToTree(this.getExecutionRoleArn()));
            if (this.getContainers() != null) {
                data.set("containers", om.valueToTree(this.getContainers()));
            }
            if (this.getModelName() != null) {
                data.set("modelName", om.valueToTree(this.getModelName()));
            }
            if (this.getPrimaryContainer() != null) {
                data.set("primaryContainer", om.valueToTree(this.getPrimaryContainer()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }
            if (this.getVpcConfig() != null) {
                data.set("vpcConfig", om.valueToTree(this.getVpcConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-sagemaker.CfnModelProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnModelProps.Jsii$Proxy that = (CfnModelProps.Jsii$Proxy) o;

            if (!executionRoleArn.equals(that.executionRoleArn)) return false;
            if (this.containers != null ? !this.containers.equals(that.containers) : that.containers != null) return false;
            if (this.modelName != null ? !this.modelName.equals(that.modelName) : that.modelName != null) return false;
            if (this.primaryContainer != null ? !this.primaryContainer.equals(that.primaryContainer) : that.primaryContainer != null) return false;
            if (this.tags != null ? !this.tags.equals(that.tags) : that.tags != null) return false;
            return this.vpcConfig != null ? this.vpcConfig.equals(that.vpcConfig) : that.vpcConfig == null;
        }

        @Override
        public int hashCode() {
            int result = this.executionRoleArn.hashCode();
            result = 31 * result + (this.containers != null ? this.containers.hashCode() : 0);
            result = 31 * result + (this.modelName != null ? this.modelName.hashCode() : 0);
            result = 31 * result + (this.primaryContainer != null ? this.primaryContainer.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            result = 31 * result + (this.vpcConfig != null ? this.vpcConfig.hashCode() : 0);
            return result;
        }
    }
}

==> sagemaker-1.43.0-sources.jar: software/amazon/awscdk/services/sagemaker/CfnModelProps.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * Properties for defining a `AWS::SageMaker::Model`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.6.0 (build 248e75b)", date = "2020-06-04T00:02:09.734Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sagemaker.$Module.class, fqn = "@aws-cdk/aws-sagemaker.CfnModelProps")
@software.amazon.jsii.Jsii.Proxy(CfnModelProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnModelProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::SageMaker::Model.ExecutionRoleArn`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-executionrolearn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getExecutionRoleArn();

    /**
     * `AWS::SageMaker::Model.Containers`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-containers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getContainers() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.ModelName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-modelname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getModelName() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.PrimaryContainer`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-primarycontainer
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getPrimaryContainer() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.Tags`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * `AWS::SageMaker::Model.VpcConfig`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#cfn-sagemaker-model-vpcconfig
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getVpcConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnModelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnModelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnModelProps> {
        private java.lang.String executionRoleArn;
        private java.lang.Object containers;
        private java.lang.String modelName;
        private java.lang.Object primaryContainer;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;
        private java.lang.Object vpcConfig;

        /**
         * Sets the value of {@link CfnModelProps#getExecutionRoleArn}
         * @param executionRoleArn `AWS::SageMaker::Model.ExecutionRoleArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder executionRoleArn(java.lang.String executionRoleArn) {
            this.executionRoleArn = executionRoleArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getContainers}
         * @param containers `AWS::SageMaker::Model.Containers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder containers(software.amazon.awscdk.core.IResolvable containers) {
            this.containers = containers;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getContainers}
         * @param containers `AWS::SageMaker::Model.Containers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder containers(java.util.List<java.lang.Object> containers) {
            this.containers = containers;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getModelName}
         * @param modelName `AWS::SageMaker::Model.ModelName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder modelName(java.lang.String modelName) {
            this.modelName = modelName;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getPrimaryContainer}
         * @param primaryContainer `AWS::SageMaker::Model.PrimaryContainer`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder primaryContainer(software.amazon.awscdk.core.IResolvable primaryContainer) {
            this.primaryContainer = primaryContainer;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getPrimaryContainer}
         * @param primaryContainer `AWS::SageMaker::Model.PrimaryContainer`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder primaryContainer(software.amazon.awscdk.services.sagemaker.CfnModel.ContainerDefinitionProperty primaryContainer) {
            this.primaryContainer = primaryContainer;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getTags}
         * @param tags `AWS::SageMaker::Model.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getVpcConfig}
         * @param vpcConfig `AWS::SageMaker::Model.VpcConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpcConfig(software.amazon.awscdk.core.IResolvable vpcConfig) {
            this.vpcConfig = vpcConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnModelProps#getVpcConfig}
         * @param vpcConfig `AWS::SageMaker::Model.VpcConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpcConfig(software.amazon.awscdk.services.sagemaker.CfnModel.VpcConfigProperty vpcConfig) {
            this.vpcConfig = vpcConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnModelProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnModelProps build() {
            return new Jsii$Proxy(executionRoleArn, containers, modelName, primaryContainer, tags, vpcConfig);
        }
    }

    /**
     * An implementation for {@link CfnModelProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnModelProps {
        private final java.lang.String executionRoleArn;
        private final java.lang.Object containers;
        private final java.lang.String modelName;
        private final java.lang.Object primaryContainer;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;
        private final java.lang.Object vpcConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.executionRoleArn = this.jsiiGet("executionRoleArn", java.lang.String.class);
            this.containers = this.jsiiGet("containers", java.lang.Object.class);
            this.modelName = this.jsiiGet("modelName", java.lang.String.class);
            this.primaryContainer = this.jsiiGet("primaryContainer", java.lang.Object.class);
            this.tags = this.jsiiGet("tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
            this.vpcConfig = this.jsiiGet("vpcConfig", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String executionRoleArn, final java.lang.Object containers, final java.lang.String modelName, final java.lang.Object primaryContainer, final java.util.List<software.amazon.awscdk.core.CfnTag> tags, final java.lang.Object vpcConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.executionRoleArn = java.util.Objects.requireNonNull(executionRoleArn, "executionRoleArn is required");
            this.containers = containers;
            this.modelName = modelName;
            this.primaryContainer = primaryContainer;
            this.tags = tags;
            this.vpcConfig = vpcConfig;
        }

        @Override
        public java.lang.String getExecutionRoleArn() {
            return this.executionRoleArn;
        }

        @Override
        public java.lang.Object getContainers() {
            return this.containers;
        }

        @Override
        public java.lang.String getModelName() {
            return this.modelName;
        }

        @Override
        public java.lang.Object getPrimaryContainer() {
            return this.primaryContainer;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        public java.lang.Object getVpcConfig() {
            return this.vpcConfig;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("executionRoleArn", om.valueToTree(this.getExecutionRoleArn()));
            if (this.getContainers() != null) {
                data.set("containers", om.valueToTree(this.getContainers()));
            }
            if (this.getModelName() != null) {
                data.set("modelName", om.valueToTree(this.getModelName()));
            }
            if (this.getPrimaryContainer() != null) {
                data.set("primaryContainer", om.valueToTree(this.getPrimaryContainer()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }
            if (this.getVpcConfig() != null) {
                data.set("vpcConfig", om.valueToTree(this.getVpcConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-sagemaker.CfnModelProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnModelProps.Jsii$Proxy that = (CfnModelProps.Jsii$Proxy) o;

            if (!executionRoleArn.equals(that.executionRoleArn)) return false;
            if (this.containers != null ? !this.containers.equals(that.containers) : that.containers != null) return false;
            if (this.modelName != null ? !this.modelName.equals(that.modelName) : that.modelName != null) return false;
            if (this.primaryContainer != null ? !this.primaryContainer.equals(that.primaryContainer) : that.primaryContainer != null) return false;
            if (this.tags != null ? !this.tags.equals(that.tags) : that.tags != null) return false;
            return this.vpcConfig != null ? this.vpcConfig.equals(that.vpcConfig) : that.vpcConfig == null;
        }

        @Override
        public int hashCode() {
            int result = this.executionRoleArn.hashCode();
            result = 31 * result + (this.containers != null ? this.containers.hashCode() : 0);
            result = 31 * result + (this.modelName != null ? this.modelName.hashCode() : 0);
            result = 31 * result + (this.primaryContainer != null ? this.primaryContainer.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            result = 31 * result + (this.vpcConfig != null ? this.vpcConfig.hashCode() : 0);
            return result;
        }
    }
}
